==> huaweicloudsdkmetastudio-3.1.96-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/inference_action_mark_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InferenceActionMarkInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'action_info': 'list[ActionMarkItem]'
    }

    attribute_map = {
        'action_info': 'action_info'
    }

    def __init__(self, action_info=None):
        """InferenceActionMarkInfo

        The model defined in huaweicloud sdk

        :param action_info: 动作列表。
        :type action_info: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        
        

        self._action_info = None
        self.discriminator = None

        if action_info is not None:
            self.action_info = action_info

    @property
    def action_info(self):
        """Gets the action_info of this InferenceActionMarkInfo.

        动作列表。

        :return: The action_info of this InferenceActionMarkInfo.
        :rtype: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        return self._action_info

    @action_info.setter
    def action_info(self, action_info):
        """Sets the action_info of this InferenceActionMarkInfo.

        动作列表。

        :param action_info: The action_info of this InferenceActionMarkInfo.
        :type action_info: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        self._action_info = action_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InferenceActionMarkInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/inference_action_mark_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InferenceActionMarkInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'action_info': 'list[ActionMarkItem]'
    }

    attribute_map = {
        'action_info': 'action_info'
    }

    def __init__(self, action_info=None):
        r"""InferenceActionMarkInfo

        The model defined in huaweicloud sdk

        :param action_info: 动作列表。
        :type action_info: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        
        

        self._action_info = None
        self.discriminator = None

        if action_info is not None:
            self.action_info = action_info

    @property
    def action_info(self):
        r"""Gets the action_info of this InferenceActionMarkInfo.

        动作列表。

        :return: The action_info of this InferenceActionMarkInfo.
        :rtype: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        return self._action_info

    @action_info.setter
    def action_info(self, action_info):
        r"""Sets the action_info of this InferenceActionMarkInfo.

        动作列表。

        :param action_info: The action_info of this InferenceActionMarkInfo.
        :type action_info: list[:class:`huaweicloudsdkmetastudio.v1.ActionMarkItem`]
        """
        self._action_info = action_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InferenceActionMarkInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
